@@ -161,6 +161,7 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 		Line	line = table.getLineReplica( 1 );
 		table.removeLine( 1, -1 );
 		cnt = org_html.size();
+		String	ex_path = null;
 		for ( int i = 0; i< cnt; i++ ) {
 			PrePage	page = page_map.get( org_html.get( i ) );
 			Line	l = (Line)line.getReplica();
@@ -175,14 +176,26 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			);
 			String	note = page.getNote();
 			if ( note == null )	note = "";
+			Column[]	column = l.getColumnArray();
 			if ( !note.isEmpty() ) {
-				Column[]	column = l.getColumnArray();
 				Column	note_column = column[column.length - 1];
 				note_column.setValueString( note );
 				note_column.setAttribute( new ColorAttribute( "bgcolor", new Color( WebColor.YELLOW ) ) );
 			}
+			Column	path_clm = column[column.length - 2];
+			String	path_str = path_clm.getValueString();
+			if ( ex_path == null )	ex_path = path_str;
+			Tag	tag = new Tag( "a", false );
+			tag.setAttribute( new Attribute( "href", "javascript:load('" + path_str + "');" ) );
+			tag.setValueString( path_str );
+			path_clm.removeHTMLPart();
+			path_clm.addHTMLPart( tag );
 			table.addLine( l );
 		}
+		Tag[]	ex = getExTags();
+		for ( int i = 0; i < ex.length; i++ ) {
+			ex[i].setValueString( ex_path );
+		}
 
 		table = getExListTable();
 		line = table.getLineReplica( 1 );
@@ -377,7 +390,7 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 		Text	text = null;
 		if ( div.getHTMLPartCount() == 0 ) {
 			text = new Text( "" );
-			getEchoDiv().addHTMLPart( text );
+			div.addHTMLPart( text );
 		}
 		else {
 			text = (Text)div.getHTMLPart( 0 );
